function newprin = interest(prin,ndays) 
% INTEREST, For calculating total amount owed, after ndays,
%     starting with prin, compounding daily, at rate of 6% per anum
% Inputs:
%     prin      - Starting Principle
%     ndays     - Number of Days
% Output:
%     newprin   - Total Amount Owed

format bank ;
newprin = prin * (1 + (0.06 / 365.25)) .^ndays ;